PyXMake Developer Guide: PyXMake.Tools.ErrorHandling.TransitionError Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Tools.ErrorHandling.TransitionError Class Reference

Base class for all transition errors. More...

Inheritance diagram for PyXMake.Tools.ErrorHandling.TransitionError:

## Public Member Functions
def | __init__ (self, Previous, Following, Message)
Public Member Functions inherited from PyXMake.Tools.ErrorHandling.Error
def | __getstate__ (self)
def | __setstate__ (self, _dict)

## Public Attributes
| Previous
| State at beginning of transition. More...
| Following
| Attempted new state. More...
| Message
| Explanation of why the specific transition is not allowed. More...

## Detailed Description

Base class for all transition errors.

    Raised when an operation attempts a state transition that's not allowed.

    Attributes:
    Previous -- State at beginning of transition
    Following -- Attempted new state
    Message -- Explanation of why the specific transition is not allowed

Inherited from Error.

Definition at line 104 of file ErrorHandling.py.

## Constructor & Destructor Documentation

## ◆ __init__()

def PyXMake.Tools.ErrorHandling.TransitionError.__init__ | ( |  | self,
|  |  | Previous,
|  |  | Following,
|  |  | Message
| ) |  |

    Low-level initialization of transition error class.

Definition at line 113 of file ErrorHandling.py.

## Member Data Documentation

## ◆ Following

PyXMake.Tools.ErrorHandling.TransitionError.Following

Attempted new state.

Definition at line 120 of file ErrorHandling.py.

## ◆ Message

PyXMake.Tools.ErrorHandling.TransitionError.Message

Explanation of why the specific transition is not allowed.

Definition at line 122 of file ErrorHandling.py.

## ◆ Previous

PyXMake.Tools.ErrorHandling.TransitionError.Previous

State at beginning of transition.

Definition at line 118 of file ErrorHandling.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Tools/ErrorHandling.py